@@ -24,8 +24,14 @@ class ApiKey(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SecretId: 密钥ID
+        :type SecretId: str
+        :param CreateTime: 创建时间(时间戳)
+        :type CreateTime: int
+        :param Status: 状态(2:有效, 3:禁用, 4:已删除)
+        :type Status: int
         """
-        :param SecretId: 密钥ID\n        :type SecretId: str\n        :param CreateTime: 创建时间(时间戳)\n        :type CreateTime: int\n        :param Status: 状态(2:有效, 3:禁用, 4:已删除)\n        :type Status: int\n        """
         self.SecretId = None
         self.CreateTime = None
         self.Status = None
@@ -50,18 +56,28 @@ class AssumeRoleRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RoleArn: 角色的资源描述，可在[访问管理](https://console.cloud.tencent.com/cam/role)，点击角色名获取。
 普通角色：
 qcs::cam::uin/12345678:role/4611686018427397919、qcs::cam::uin/12345678:roleName/testRoleName
 服务角色：
-qcs::cam::uin/12345678:role/tencentcloudServiceRole/4611686018427397920、qcs::cam::uin/12345678:role/tencentcloudServiceRoleName/testServiceRoleName\n        :type RoleArn: str\n        :param RoleSessionName: 临时会话名称，由用户自定义名称。
-长度在2到128之间，可包含大小写字符，数字以及特殊字符：=,.@_-。 正则为：[\w+=,.@_-]*\n        :type RoleSessionName: str\n        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认 7200 秒，最长可设定有效期为 43200 秒\n        :type DurationSeconds: int\n        :param Policy: 策略描述
+qcs::cam::uin/12345678:role/tencentcloudServiceRole/4611686018427397920、qcs::cam::uin/12345678:role/tencentcloudServiceRoleName/testServiceRoleName
+        :type RoleArn: str
+        :param RoleSessionName: 临时会话名称，由用户自定义名称。
+长度在2到128之间，可包含大小写字符，数字以及特殊字符：=,.@_-。 正则为：[\w+=,.@_-]*
+        :type RoleSessionName: str
+        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认 7200 秒，最长可设定有效期为 43200 秒
+        :type DurationSeconds: int
+        :param Policy: 策略描述
 注意：
 1、policy 需要做 urlencode（如果通过 GET 方法请求云 API，发送请求前，所有参数都需要按照[云 API 规范](https://cloud.tencent.com/document/api/598/33159#1.-.E6.8B.BC.E6.8E.A5.E8.A7.84.E8.8C.83.E8.AF.B7.E6.B1.82.E4.B8.B2)再 urlencode 一次）。
 2、策略语法参照[ CAM 策略语法](https://cloud.tencent.com/document/product/598/10603)。
-3、策略中不能包含 principal 元素。\n        :type Policy: str\n        :param ExternalId: 角色外部ID，可在[访问管理](https://console.cloud.tencent.com/cam/role)，点击角色名获取。
-长度在2到128之间，可包含大小写字符，数字以及特殊字符：=,.@:/-。 正则为：[\w+=,.@:\/-]*\n        :type ExternalId: str\n        """
+3、策略中不能包含 principal 元素。
+        :type Policy: str
+        :param ExternalId: 角色外部ID，可在[访问管理](https://console.cloud.tencent.com/cam/role)，点击角色名获取。
+长度在2到128之间，可包含大小写字符，数字以及特殊字符：=,.@:/-。 正则为：[\w+=,.@:\/-]*
+        :type ExternalId: str
+        """
         self.RoleArn = None
         self.RoleSessionName = None
         self.DurationSeconds = None
@@ -90,8 +106,16 @@ class AssumeRoleResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Credentials: 临时安全证书
+        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`
+        :param ExpiredTime: 证书无效的时间，返回 Unix 时间戳，精确到秒
+        :type ExpiredTime: int
+        :param Expiration: 证书无效的时间，以 iso8601 格式的 UTC 时间表示
+        :type Expiration: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Credentials: 临时安全证书\n        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`\n        :param ExpiredTime: 证书无效的时间，返回 Unix 时间戳，精确到秒\n        :type ExpiredTime: int\n        :param Expiration: 证书无效的时间，以 iso8601 格式的 UTC 时间表示\n        :type Expiration: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Credentials = None
         self.ExpiredTime = None
         self.Expiration = None
@@ -113,8 +137,18 @@ class AssumeRoleWithSAMLRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param SAMLAssertion: base64 编码的 SAML 断言信息
+        :type SAMLAssertion: str
+        :param PrincipalArn: 扮演者访问描述名
+        :type PrincipalArn: str
+        :param RoleArn: 角色访问描述名
+        :type RoleArn: str
+        :param RoleSessionName: 会话名称
+        :type RoleSessionName: str
+        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认 7200 秒，最长可设定有效期为 43200 秒
+        :type DurationSeconds: int
         """
-        :param SAMLAssertion: base64 编码的 SAML 断言信息\n        :type SAMLAssertion: str\n        :param PrincipalArn: 扮演者访问描述名\n        :type PrincipalArn: str\n        :param RoleArn: 角色访问描述名\n        :type RoleArn: str\n        :param RoleSessionName: 会话名称\n        :type RoleSessionName: str\n        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认 7200 秒，最长可设定有效期为 43200 秒\n        :type DurationSeconds: int\n        """
         self.SAMLAssertion = None
         self.PrincipalArn = None
         self.RoleArn = None
@@ -143,8 +177,16 @@ class AssumeRoleWithSAMLResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Credentials: 对象里面包含 Token，TmpSecretId，TmpSecretKey 三元组
+        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`
+        :param ExpiredTime: 证书无效的时间，返回 Unix 时间戳，精确到秒
+        :type ExpiredTime: int
+        :param Expiration: 证书无效的时间，以 ISO8601 格式的 UTC 时间表示
+        :type Expiration: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Credentials: 对象里面包含 Token，TmpSecretId，TmpSecretKey 三元组\n        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`\n        :param ExpiredTime: 证书无效的时间，返回 Unix 时间戳，精确到秒\n        :type ExpiredTime: int\n        :param Expiration: 证书无效的时间，以 ISO8601 格式的 UTC 时间表示\n        :type Expiration: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Credentials = None
         self.ExpiredTime = None
         self.Expiration = None
@@ -166,8 +208,14 @@ class Credentials(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Token: token。token长度和绑定的策略有关，最长不超过4096字节。
+        :type Token: str
+        :param TmpSecretId: 临时证书密钥ID。最长不超过1024字节。
+        :type TmpSecretId: str
+        :param TmpSecretKey: 临时证书密钥Key。最长不超过1024字节。
+        :type TmpSecretKey: str
         """
-        :param Token: token。token长度和绑定的策略有关，最长不超过4096字节。\n        :type Token: str\n        :param TmpSecretId: 临时证书密钥ID。最长不超过1024字节。\n        :type TmpSecretId: str\n        :param TmpSecretKey: 临时证书密钥Key。最长不超过1024字节。\n        :type TmpSecretKey: str\n        """
         self.Token = None
         self.TmpSecretId = None
         self.TmpSecretKey = None
@@ -186,18 +234,72 @@ class Credentials(AbstractModel):
         
 
 
+class GetCallerIdentityRequest(AbstractModel):
+    """GetCallerIdentity请求参数结构体
+
+    """
+
+
+class GetCallerIdentityResponse(AbstractModel):
+    """GetCallerIdentity返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Arn: 当前调用者ARN。
+        :type Arn: str
+        :param AccountId: 当前调用者所属主账号Uin。
+        :type AccountId: str
+        :param UserId: 身份标识。
+1. 调用者是云账号时，返回的是当前账号Uin
+2. 调用者是角色时，返回的是roleId:roleSessionName
+3. 调用者是联合身份时，返回的是uin:federatedUserName
+        :type UserId: str
+        :param PrincipalId: 密钥所属账号Uin。
+1. 调用者是云账号，返回的当前账号Uin
+2, 调用者是角色，返回的申请角色密钥的账号Uin
+        :type PrincipalId: str
+        :param Type: 身份类型。
+        :type Type: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Arn = None
+        self.AccountId = None
+        self.UserId = None
+        self.PrincipalId = None
+        self.Type = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Arn = params.get("Arn")
+        self.AccountId = params.get("AccountId")
+        self.UserId = params.get("UserId")
+        self.PrincipalId = params.get("PrincipalId")
+        self.Type = params.get("Type")
+        self.RequestId = params.get("RequestId")
+
+
 class GetFederationTokenRequest(AbstractModel):
     """GetFederationToken请求参数结构体
 
     """
 
     def __init__(self):
-        """
-        :param Name: 您可以自定义调用方英文名称，由字母组成。\n        :type Name: str\n        :param Policy: 授予该临时证书权限的CAM策略
+        r"""
+        :param Name: 您可以自定义调用方英文名称，由字母组成。
+        :type Name: str
+        :param Policy: 授予该临时证书权限的CAM策略
 注意：
 1、策略语法参照[ CAM 策略语法](https://cloud.tencent.com/document/product/598/10603)。
 2、策略中不能包含 principal 元素。
-3、该参数需要做urlencode。\n        :type Policy: str\n        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认1800秒，主账号最长可设定有效期为7200秒，子账号最长可设定有效期为129600秒。\n        :type DurationSeconds: int\n        """
+3、该参数需要做urlencode。
+        :type Policy: str
+        :param DurationSeconds: 指定临时证书的有效期，单位：秒，默认1800秒，主账号最长可设定有效期为7200秒，子账号最长可设定有效期为129600秒。
+        :type DurationSeconds: int
+        """
         self.Name = None
         self.Policy = None
         self.DurationSeconds = None
@@ -222,9 +324,17 @@ class GetFederationTokenResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param Credentials: 临时证书
+        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`
+        :param ExpiredTime: 临时证书有效的时间，返回 Unix 时间戳，精确到秒
+        :type ExpiredTime: int
+        :param Expiration: 证书有效的时间，以 iso8601 格式的 UTC 时间表示
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Expiration: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param Credentials: 临时证书\n        :type Credentials: :class:`tencentcloud.sts.v20180813.models.Credentials`\n        :param ExpiredTime: 临时证书有效的时间，返回 Unix 时间戳，精确到秒\n        :type ExpiredTime: int\n        :param Expiration: 证书有效的时间，以 iso8601 格式的 UTC 时间表示
-注意：此字段可能返回 null，表示取不到有效值。\n        :type Expiration: str\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.Credentials = None
         self.ExpiredTime = None
         self.Expiration = None
@@ -246,8 +356,10 @@ class QueryApiKeyRequest(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param TargetUin: 待查询的账号(不填默认查当前账号)
+        :type TargetUin: int
         """
-        :param TargetUin: 待查询的账号(不填默认查当前账号)\n        :type TargetUin: int\n        """
         self.TargetUin = None
 
 
@@ -268,8 +380,12 @@ class QueryApiKeyResponse(AbstractModel):
     """
 
     def __init__(self):
+        r"""
+        :param IdKeys: 密钥ID列表
+        :type IdKeys: list of ApiKey
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
         """
-        :param IdKeys: 密钥ID列表\n        :type IdKeys: list of ApiKey\n        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。\n        :type RequestId: str\n        """
         self.IdKeys = None
         self.RequestId = None
 
